@@ -79,13 +79,13 @@ public:
     QString name() const { return m_name->text(); }
     
     /** Sets the variables class to be used with the graph functions*/
-    void setVariables(Analitza::Variables* v) { m_vars=v; }
+    void setVariables(const QSharedPointer<Analitza::Variables> &v) { m_vars=v; }
     
-    Analitza::Variables* variables() const { return m_vars; }
+    QSharedPointer<Analitza::Variables> variables() const { return m_vars; }
     
     void setOptionsShown(bool shown);
     
-    virtual void resizeEvent(QResizeEvent* ev);
+    void resizeEvent(QResizeEvent* ev) Q_DECL_OVERRIDE;
     
 public Q_SLOTS:
     /** Clears the dialog. */
@@ -107,7 +107,7 @@ private Q_SLOTS:
     
 private:
     void setState(const QString& text, bool negative);
-    void focusInEvent(QFocusEvent*);
+    void focusInEvent(QFocusEvent*) Q_DECL_OVERRIDE;
     
     Analitza::ExpressionEdit *m_func;
     Analitza::ExpressionEdit *m_uplimit, *m_downlimit;
@@ -119,7 +119,7 @@ private:
     Analitza::PlotsView2D *m_graph;
     KColorCombo *m_color;
     Analitza::PlotsModel *m_funcsModel;
-    Analitza::Variables* m_vars = nullptr;
+    QSharedPointer<Analitza::Variables> m_vars;
     
     bool m_modmode;
     QTabWidget* m_viewTabs;
